package com.alihealth.d2d.provtest.service.handle.business;

import com.alihealth.d2d.provtest.domain.DrugImportApplyInfo;
import com.alihealth.d2d.provtest.entity.EventBasic;
import com.alihealth.d2d.provtest.entity.EventBody;
import com.alihealth.d2d.provtest.entity.InstanceDetail;
import com.alihealth.d2d.provtest.entity.ItemDetail;
import com.alihealth.d2d.provtest.service.IDrugImportApplyInfoService;
import com.alihealth.d2d.provtest.service.handle.AbstractEventDataHandler;
import com.alihealth.d2d.provtest.service.handle.EventSubType;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;

/**
 * @author Jason
 * @date 2025年06月05日 11:37:18
 */
@Service
@EventSubType("2012")
public class SubType2012Handler extends AbstractEventDataHandler<DrugImportApplyInfo> {

    @Autowired
    private IDrugImportApplyInfoService service;

    @Override
    protected Class<DrugImportApplyInfo> getEntityClass() {
        return DrugImportApplyInfo.class;
    }

    @Override
    protected IService<DrugImportApplyInfo> getService() {
        return service;
    }

    @Override
    protected DrugImportApplyInfo convertToEntity(EventBody eventBody, ItemDetail item, InstanceDetail instance,String eventId) {
        EventBasic evtBasic = eventBody.getEvtBasic();
        //时间格式
        SimpleDateFormat formatterDatetime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //日期格式
        SimpleDateFormat formatterDate = new SimpleDateFormat("yyyyMMdd");
        try {
            return DrugImportApplyInfo.builder()
                    .eventId(eventId)
                    .recTime(formatterDatetime.parse(eventBody.getRecTime()))

                    .rksj(evtBasic.getString("RKSJ") != null ? formatterDatetime.parse(evtBasic.getString("RKSJ")) : null)
                    .recTime(formatterDatetime.parse(eventBody.getRecTime()))
                    .rkdbh(evtBasic.getString("RKDBH"))

                    .ypzsm(instance.getString("YPZSM"))
                    .syjbzypzsm(instance.getString("SYJBZYPZSM"))
                    .bzcj(instance.getString("BZCJ"))
                    .ymzt(instance.getString("YMZT"))

                    .tyshxydmjkypdlqy(item.getString("TYSHXYDMJKYPDLQY"))
                    .jkypdlqymc(item.getString("JKYPDLQYMC"))
                    .jwypssxkcyrdm(item.getString("JWYPSSXKCYRDM"))
                    .jwypssxkcyrmczw(item.getString("JWYPSSXKCYRMCZW"))
                    .jwypscqydm(item.getString("JWYPSCQYDM"))
                    .jwypscqymczw(item.getString("JWYPSCQYMCZW"))
                    .tyshxydmfbzc(item.getString("TYSHXYDMFBZC"))
                    .fbzcmc(item.getString("FBZCMC"))
                    .yptymc(item.getString("YPTYMC"))
                    .gjypbsm(item.getString("GJYPBSM"))
                    .ymscph(item.getString("YMSCPH"))
                    .scrq(formatterDate.parse(item.getString("SCRQ")))
                    .ypyxqjzrq(formatterDate.parse(item.getString("YPYXQJZRQ")))
                    .ypspmc(item.getString("YPSPMC"))
                    .ypbwm(item.getString("YPBWM"))
                    .jx(item.getString("JX"))
                    .zjgg(item.getString("ZJGG"))
                    .bzgg(item.getString("BZGG"))
                    .bzzhb(Integer.parseInt(item.getString("BZZHB")))
                    .ypyxq(Integer.parseInt(item.getString("YPYXQ")))
                    .ypyxqdw(item.getString("YPYXQDW"))
                    .yppzwh(item.getString("YPPZWH"))
                    .yppzwhyxq(formatterDate.parse(item.getString("YPPZWHYXQ")))
                    .ypscph(item.getString("YPSCPH"))

                    .scsl(item.getInt("SCSL"))
                    .build();
        } catch (ParseException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public String getSubType() {
        return "2012";
    }

    @Override
    public void handleBase(String xml, String eventId) {

    }
}
